/******************************************************************************
 * Copyright 1997, Swiss Federal Institute of Technology, Zuerich (ETHZ)
 *
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the name of ETHZ not be used in advertising or
 * publicity pertaining to distribution of the software without specific,
 * written prior permission.  ETHZ makes no representations about the
 * suitability of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 *
 * ETHZ DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL ETHZ
 * BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
 * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
-------------------------------------------------------------------------------
 Project:               Crossbow (IP Next Generation, with WashU's ARL)
-------------------------------------------------------------------------------

 File:			$Source: /home/arl/arlsw/mwa/Admin/cvsroot/home/mwa/src/error/LogCompatibility.c,v $
 Author(s):		Marcel Waldvogel
 Affiliation:		ETH Zuerich, TIK
 Version:		$Revision: 1.1 $
 Creation Date:		13.06.1997
 Last Changed:		$Date: 1997/11/29 16:22:59 $ by $Author: mwa $
-------------------------------------------------------------------------------
 
*Concept and Idea:
    Maps Error.[ch] functionality onto log()
    
*Performed Functions:
    
*Global Variables in Use:
    
*Extern Declarations in Use:
     
-------------------------------------------------------------------------------
 
*Solved Errors (Function, Type of Error, Solution, Author, Date):
 * $Log: LogCompatibility.c,v $
 * Revision 1.1  1997/11/29 16:22:59  mwa
 * Ignore Error.c also, added LogCompatibility.[ch] (preliminary)
 *
 * Revision 1.1  1997/06/23 12:07:22  mwa
 * Initial revision
 *
-------------------------------------------------------------------------------
 
*Remarks:
 
*****************************************************************************/

#include "LogCompatibility.h"
#include <syslog.h>


/****************************************************************************
 * Performed Function : Like syslog(), but logs using Error.[ch]
 * Input Parameter    : priority, message (printf-String) and printf-Parameters
 * Output Parameter   : None 
 * Handled Errors     : None
 * Error Codes        : None
 ***************************************************************************/
void
log(int priority, const char *message, ...)
{
    va_list       ap;
    ErrorSeverity es;

    switch(priority) {
    case LOG_DEBUG:     es = esDebug; break;
    case LOG_INFO:      es = esInfo; break;
    case LOG_NOTICE:    es = esInfo; break;
    case LOG_WARNING:   es = esWarning; break;
    case LOG_ERR:       es = esError; break;
    case LOG_CRIT:      es = esFatal; break;
    case LOG_ALERT:     es = esFatal; break;
    case LOG_EMERG:     es = esFatal; break;
    default:
        ABORT(ecError, "logCompatibility", "Unknown priority %d (msg=%s)",
              priority, message);
    }
    va_start(ap, message);
    ErrorVLogMessage(ecGeneric, NULL, es, NULL, NULL, message, ap);
    va_end(ap);
}

/****************************************************************************
 * Performed Function : Like panic(), but logs using Error.[ch]
 *                      and allows parameters
 * Input Parameter    : message (printf-String) and printf-Parameters
 * Output Parameter   : None 
 * Handled Errors     : None
 * Error Codes        : None
 ***************************************************************************/
void
panic(const char *message, ...)
{
    va_list       ap;

    va_start(ap, message);
    ErrorVLogMessage(ecGeneric, NULL, esAbort, NULL, NULL, message, ap);
    va_end(ap);
    ErrorAbort(1, 0);
}

